@@ -12,6 +12,7 @@ functions are called whenever a signal is called.
     :ref:`signals` for more information.
 """
 from __future__ import absolute_import, unicode_literals
+
 from .utils.dispatch import Signal
 
 __all__ = [
@@ -19,8 +20,8 @@ __all__ = [
     'task_prerun', 'task_postrun', 'task_success',
     'task_retry', 'task_failure', 'task_revoked', 'celeryd_init',
     'celeryd_after_setup', 'worker_init', 'worker_process_init',
-    'worker_ready', 'worker_shutdown', 'setup_logging',
-    'after_setup_logger', 'after_setup_task_logger',
+    'worker_ready', 'worker_shutdown', 'worker_shutting_down',
+    'setup_logging', 'after_setup_logger', 'after_setup_task_logger',
     'beat_init', 'beat_embedded_init', 'heartbeat_sent',
     'eventlet_pool_started', 'eventlet_pool_preshutdown',
     'eventlet_pool_postshutdown', 'eventlet_pool_apply',
@@ -99,6 +100,7 @@ worker_process_init = Signal(name='worker_process_init')
 worker_process_shutdown = Signal(name='worker_process_shutdown')
 worker_ready = Signal(name='worker_ready')
 worker_shutdown = Signal(name='worker_shutdown')
+worker_shutting_down = Signal(name='worker_shutting_down')
 heartbeat_sent = Signal(name='heartbeat_sent')
 
 # - Logging
